@@ -31,6 +31,7 @@ import sys
 # -----------------------------------------------------------------
 
 class Camera(BaseCamera):
+
     video_source = 0
     histomean = 50
 
@@ -121,6 +122,11 @@ class Camera(BaseCamera):
         rotate180    = int(config.CONFIG['otate'])
         zoom         = int(config.CONFIG['zoom'])
 
+        MODE_DMbase = "MODE DM"
+        MODE_DM = "MODE DM"
+        imagezmq = None
+        if 'imagezmq' in config.CONFIG:
+            imagezmq     = config.CONFIG['imagezmq']
 
         print( "XY: ", config.CONFIG['x'] ,  config.CONFIG['y']  , speedx, speedy)
 
@@ -611,7 +617,14 @@ class Camera(BaseCamera):
 
                     # ----  for detmo ---- work with detect motion--------------------
                     if (threshold>0) :
-                        senh.setbox("MODE DM", senh.MODE) #---push UP to avoid DetMot
+                        # here there was MODE DM.
+                        # but with imageZMQ and Telegram ALERT....
+                        #
+                        if not imagezmq is None:
+                            MODE_DM=MODE_DMbase+"z"
+                            if os.path.exists(os.path.expanduser("~/.telegram.token")):
+                                MODE_DM=MODE_DM+"T"
+                        senh.setbox(MODE_DM, senh.MODE) #---push UP to avoid DetMot
                         senh.detmo( average, blur)
                         senh.chk_threshold( threshold )
                         if senh.motion_detected: # saving avi on mation detect
