@@ -21,9 +21,14 @@ import socket
 import time
 from imutils.video import VideoStream
 import imagezmq
+import zmq # for timeouts??
 import threading
 
 
+import notifator.telegram as telegram
+
+
+
 class Stream_Enhancer:
     """
     definitions of positions on the frame
@@ -95,6 +100,7 @@ class Stream_Enhancer:
     zmqtarget = None
     zmqsender = None
     zmqlast = dt.datetime.now()
+    telegramlast = dt.datetime.now()
 
 
     def RC_COLOR(self,row,col):
@@ -813,6 +819,12 @@ class Stream_Enhancer:
                 print("!... getting zmq sender:", self.zmqtarget)
                 if not self.zmqtarget is None:
                     self.zmqsender = imagezmq.ImageSender(connect_to=f'tcp://{self.zmqtarget}:5555')
+                    self.zmqsender.zmq_socket.setsockopt(zmq.LINGER, 0)  # prevents ZMQ hang on exit
+                    # NOTE: because of the way PyZMQ and imageZMQ are implemented, the
+                    #       timeout values specified must be integer constants, not variables.
+                    #       The timeout value is in milliseconds, e.g., 2000 = 2 seconds.
+                    self.zmqsender.zmq_socket.setsockopt(zmq.RCVTIMEO, 2000)  # set a receive timeout
+                    self.zmqsender.zmq_socket.setsockopt(zmq.SNDTIMEO, 2000)  # set a send timeout
                     print("!... got it", self.zmqsender)
 
                 fourcc = cv2.VideoWriter_fourcc(*'XVID')
@@ -840,15 +852,31 @@ class Stream_Enhancer:
 
             if  (self.zmqsender is None) and (not self.zmqtarget is None):
                 self.zmqsender = imagezmq.ImageSender(connect_to=f'tcp://{self.zmqtarget}:5555')
+                self.zmqsender.zmq_socket.setsockopt(zmq.LINGER, 0)  # prevents ZMQ hang on exit
+                # NOTE: because of the way PyZMQ and imageZMQ are implemented, the
+                #       timeout values specified must be integer constants, not variables.
+                #       The timeout value is in milliseconds, e.g., 2000 = 2 seconds.
+                self.zmqsender.zmq_socket.setsockopt(zmq.RCVTIMEO, 2000)  # set a receive timeout
+                self.zmqsender.zmq_socket.setsockopt(zmq.SNDTIMEO, 2000)  # set a send timeout
+
 
             if not self.zmqsender is None:
                 zmqnow = dt.datetime.now()
+                telegramnow = zmqnow
+
+
+                if (telegramnow-self.telegramlast).total_seconds()>300:
+                    y = threading.Thread(target=telegram.bot_send, args=("ALERT", f"CAMERA {self.zmqrpi_name} {zmqnow.strftime('%a %H:%M:%S')}", self.frame))
+                    y.start()
+                    self.telegramlast=telegramnow
+
+
                 if (zmqnow-self.zmqlast).total_seconds()>1.5:
                     x = threading.Thread(target=self.zmqsender.send_image, args=(self.zmqrpi_name, self.frame))
                     x.start()
                     #self.zmqsender.send_image(self.zmqrpi_name, self.frame)
                     self.zmqlast=zmqnow
-                    print(f"i... zmq is sent to {self.zmqtarget}")
+                    print(f"i... zmq is being sent to {self.zmqtarget}")
         # -------------- timelapse if seconds>0:
         elif seconds>0:
             if not self.aviopened_laps:
